==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/S_SYNCSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.FunctionBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.FunctionBodySetImpl;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNC;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.FunctionParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.FunctionInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.FunctionInvocationSetImpl;
import io.ciera.tool.sql.ooaofooa.message.FunctionMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.FunctionMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.value.FunctionValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.FunctionValueSetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public class S_SYNCSetImpl extends InstanceSet<S_SYNCSet,S_SYNC> implements S_SYNCSet {

    // attributes
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setReturn_Dimensions( String m_Return_Dimensions ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setReturn_Dimensions( m_Return_Dimensions );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setDialect( m_Dialect );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setSync_ID( ref_Sync_ID );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setName( m_Name );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setDescrip( m_Descrip );
    }
    @Override
    public void setDom_IDdeprecated( UniqueId m_Dom_IDdeprecated ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setDom_IDdeprecated( m_Dom_IDdeprecated );
    }
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setAction_Semantics( m_Action_Semantics );
    }


    // selections
    @Override
    public FunctionMessageSet R1010_is_invoked_by_FunctionMessage() throws XtumlException {
        FunctionMessageSet functionmessageset = new FunctionMessageSetImpl();
        for ( S_SYNC s_sync : this ) functionmessageset.addAll( s_sync.R1010_is_invoked_by_FunctionMessage() );
        return functionmessageset;
    }
    @Override
    public FunctionParameterSet R24_defines_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( S_SYNC s_sync : this ) functionparameterset.addAll( s_sync.R24_defines_FunctionParameter() );
        return functionparameterset;
    }
    @Override
    public DataTypeSet R25_has_return_type_of_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( S_SYNC s_sync : this ) datatypeset.add( s_sync.R25_has_return_type_of_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R51_return_value_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( S_SYNC s_sync : this ) dimensionsset.addAll( s_sync.R51_return_value_may_have_Dimensions() );
        return dimensionsset;
    }
    @Override
    public FunctionInvocationSet R675_FunctionInvocation() throws XtumlException {
        FunctionInvocationSet functioninvocationset = new FunctionInvocationSetImpl();
        for ( S_SYNC s_sync : this ) functioninvocationset.addAll( s_sync.R675_FunctionInvocation() );
        return functioninvocationset;
    }
    @Override
    public FunctionBodySet R695_FunctionBody() throws XtumlException {
        FunctionBodySet functionbodyset = new FunctionBodySetImpl();
        for ( S_SYNC s_sync : this ) functionbodyset.add( s_sync.R695_FunctionBody() );
        return functionbodyset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( S_SYNC s_sync : this ) packageableelementset.add( s_sync.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public FunctionValueSet R827_FunctionValue() throws XtumlException {
        FunctionValueSet functionvalueset = new FunctionValueSetImpl();
        for ( S_SYNC s_sync : this ) functionvalueset.addAll( s_sync.R827_FunctionValue() );
        return functionvalueset;
    }


    @Override
    public S_SYNC nullElement() {
        return S_SYNCImpl.EMPTY_S_SYNC;
    }

    @Override
    public S_SYNCSet emptySet() {
      return new S_SYNCSetImpl();
    }

    @Override
    public S_SYNCSet value() {
        return this;
    }

    @Override
    public List<S_SYNC> elements() {
        S_SYNC[] elements = toArray(new S_SYNC[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/S_SYNCSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.FunctionBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.FunctionBodySetImpl;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNC;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.FunctionParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.FunctionInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.FunctionInvocationSetImpl;
import io.ciera.tool.sql.ooaofooa.message.FunctionMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.FunctionMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.value.FunctionValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.FunctionValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public class S_SYNCSetImpl extends InstanceSet<S_SYNCSet,S_SYNC> implements S_SYNCSet {

    public S_SYNCSetImpl() {
    }

    public S_SYNCSetImpl(Comparator<? super S_SYNC> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setDom_IDdeprecated( UniqueId m_Dom_IDdeprecated ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setDom_IDdeprecated( m_Dom_IDdeprecated );
    }
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setDialect( m_Dialect );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setDescrip( m_Descrip );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setName( m_Name );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setReturn_Dimensions( String m_Return_Dimensions ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setReturn_Dimensions( m_Return_Dimensions );
    }
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( S_SYNC s_sync : this ) s_sync.setSync_ID( ref_Sync_ID );
    }


    // selections
    @Override
    public FunctionMessageSet R1010_is_invoked_by_FunctionMessage() throws XtumlException {
        FunctionMessageSet functionmessageset = new FunctionMessageSetImpl();
        for ( S_SYNC s_sync : this ) functionmessageset.addAll( s_sync.R1010_is_invoked_by_FunctionMessage() );
        return functionmessageset;
    }
    @Override
    public FunctionParameterSet R24_defines_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( S_SYNC s_sync : this ) functionparameterset.addAll( s_sync.R24_defines_FunctionParameter() );
        return functionparameterset;
    }
    @Override
    public DataTypeSet R25_has_return_type_of_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( S_SYNC s_sync : this ) datatypeset.add( s_sync.R25_has_return_type_of_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R51_return_value_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( S_SYNC s_sync : this ) dimensionsset.addAll( s_sync.R51_return_value_may_have_Dimensions() );
        return dimensionsset;
    }
    @Override
    public FunctionInvocationSet R675_FunctionInvocation() throws XtumlException {
        FunctionInvocationSet functioninvocationset = new FunctionInvocationSetImpl();
        for ( S_SYNC s_sync : this ) functioninvocationset.addAll( s_sync.R675_FunctionInvocation() );
        return functioninvocationset;
    }
    @Override
    public FunctionBodySet R695_FunctionBody() throws XtumlException {
        FunctionBodySet functionbodyset = new FunctionBodySetImpl();
        for ( S_SYNC s_sync : this ) functionbodyset.add( s_sync.R695_FunctionBody() );
        return functionbodyset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( S_SYNC s_sync : this ) packageableelementset.add( s_sync.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public FunctionValueSet R827_FunctionValue() throws XtumlException {
        FunctionValueSet functionvalueset = new FunctionValueSetImpl();
        for ( S_SYNC s_sync : this ) functionvalueset.addAll( s_sync.R827_FunctionValue() );
        return functionvalueset;
    }


    @Override
    public S_SYNC nullElement() {
        return S_SYNCImpl.EMPTY_S_SYNC;
    }

    @Override
    public S_SYNCSet emptySet() {
      return new S_SYNCSetImpl();
    }

    @Override
    public S_SYNCSet emptySet(Comparator<? super S_SYNC> comp) {
      return new S_SYNCSetImpl(comp);
    }

    @Override
    public S_SYNCSet value() {
        return this;
    }

    @Override
    public List<S_SYNC> elements() {
        S_SYNC[] elements = toArray(new S_SYNC[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
